void ticks(unsigned char);

uchar Memory::rd(ushort adr) {
	uchar res;
	switch (adr & 0xc000) {
		case 0x0000: res = (currom==0xff) ? ram[0][adr&0x3fff] : rom[currom][adr&0x3fff]; break;
		case 0x4000: res = ram[5][adr&0x3fff]; break;
		case 0x8000: res = ram[2][adr&0x3fff]; break;
		default: res = ram[curram][adr&0x3fff]; break;
	}
	return res;
}

void Memory::wr(ushort adr,uchar val) {
	switch (adr & 0xc000) {
		case 0x0000: if (currom==0xff) ram[0][adr&0x3fff]=val; break;
		case 0x4000: ram[5][adr&0x3fff]=val; break;
		case 0x8000: ram[2][adr&0x3fff]=val; break;
		default: ram[curram][adr&0x3fff]=val; break;
	}
	return;
}

//---------
int getpair(unsigned char idx) {
	int res;
	if (idx==6) {res=(reg[7]<<8)+reg[6];} else {res=(reg[idx]<<8)+reg[idx+1];}
	return res;
}

int getaltpair(unsigned char idx) {
	int res;
	if (idx==6) {res=(alt[7]<<8)+alt[6];} else {res=(alt[idx]<<8)+alt[idx+1];}
	return res;
}

void setpair(unsigned char idx, int value) {
	unsigned char low = value & 0xff;
	unsigned char hi = (value & 0xff00)>>8;
	if (idx==6) {reg[6]=low; reg[7]=hi;} else {reg[idx]=hi; reg[idx+1]=low;}
}

void setaltpair(unsigned char idx, int value) {
	unsigned char low = value & 0xff;
	unsigned char hi = (value & 0xff00) >> 8;
	if (idx==6) {alt[6]=low; alt[7]=hi;} else {alt[idx]=hi; alt[idx+1]=low;}
}

void decpair(unsigned char idx) {setpair(idx,getpair(idx)-1);}
void incpair(unsigned char idx) {setpair(idx,getpair(idx)+1);}

//---------

bool parity(unsigned char oper) {
	unsigned char i,cnt;
	cnt=0;
	for (i=0;i<8;i++) {if ((oper & tmasks[i])!=0) cnt++;}
	return ((cnt&0x01)==0);
}

//---------

uchar getbyte(uchar tck=3) {
	uchar res=mem.rd(pc);
	ticks(tck);
	pc++;
	return res;
}

int getword(uchar tck1=3, uchar tck2=3) {return getbyte(tck1)+256*getbyte(tck2);}

uchar readmem(ushort adr, uchar tck=3) {
	ticks(tck);
	return mem.rd(adr);
}

void writemem(ushort adr, uchar value, uchar tck=3) {
	mem.wr(adr,value);
	ticks(tck);
	return;
}

ushort adddelta(ushort res,char dlt, uchar tck=5) {
	res += dlt;// if (dlt>127) res -= 256;
	ticks(tck);
	return (res&0xffff);
}

int getindex(int dlt=-1) {
	int res=getpair(4);
	if (ixpref || iypref) {
		if (ixpref) res=getpair(10);	// ix
		if (iypref) res=getpair(12);	// iy
		if (dlt==-1) dlt=getbyte();
		res=adddelta(res,dlt);	// ticks: 3+5
	}
	return res;
}

unsigned char corridx(unsigned char idx) {
	if ((idx==4) & ixpref) idx=10;
	if ((idx==5) & ixpref) idx=11;
	if ((idx==4) & iypref) idx=12;
	if ((idx==5) & iypref) idx=13;
	return idx;
}

unsigned char idxtosp(unsigned char idx) {return (idx==6?8:idx);}

void exchange(unsigned char idx) {
	unsigned char temp;
	temp=reg[idx];reg[idx]=alt[idx];alt[idx]=temp;
}

//---------

// void affectflag(unsigned char idx,bool state) {if (state) {reg[6]=reg[6] | tmasks[idx];} else {reg[6]=reg[6] & imasks[idx];}}
#define affectflag(midx,mstate) if (mstate) {reg[6]=reg[6]|tmasks[midx];} else {reg[6]=reg[6]&imasks[midx];}

// bool testflag(unsigned char idx) {return (reg[6] & tmasks[idx]);}
#define testflag(midx) (reg[6]&tmasks[midx])

bool testusl(unsigned char idx) {
	bool res;
	switch(idx) {
		case 0: res=!testflag(6); break;
		case 1: res=testflag(6); break;
		case 2: res=!testflag(0); break;
		case 3: res=testflag(0); break;
		case 4: res=!testflag(2); break;
		case 5: res=testflag(2); break;
		case 6: res=!testflag(7); break;
		case 7: res=testflag(7); break;
		default: res=false;
	}
	return res;
}

//---------

std::string int2str(int num) {std::stringstream str; str<<num; return str.str();}

//---------

void reset() {
	block7ffd=false;
	mem.curram = mem.prt0 = mem.prt1 = 0;
	mem.currom = machine->resrom;
	pc = 0; iff1 = iff2 = false;
	curscrn = false;
	gfxmode = 0;
	ayreset();
	vg93.wnum = 0xff;
	vg93.count = 0;
	vg93.setmr(false);
}

// loadrom (rompart, filename (not path), filepart)
void loadrom(uchar rpart, std::string name, uchar fpart) {
	std::string fpath = romdir + "/" + name;
	std::ifstream file(fpath.c_str(),std::ios::binary);
	if (file.good()) {
		file.seekg((fpart<<14),std::ios::beg);
		file.read((char*)&mem.rom[rpart][0],0x4000);
	} else {
		printf("Can't read ROM file %s:%i @ rom %i\n",fpath.c_str(),fpart,rpart);
		ushort i; for(i=0;i<0x4000;i++) mem.rom[rpart][i]=0xff;
	}
}

void loadmachineromset() {
	for (tmp=0;tmp<8;tmp++) {
		if (machine->romset->path[tmp]!="") {
			loadrom(tmp,machine->romset->path[tmp],machine->romset->part[tmp]);
		} else {
			for (tadr=0;tadr<0x4000;tadr++) {mem.rom[tmp][tadr]=0xff;}		// неиспользуемые
		}
	}
}

//----- keyboard

unsigned char getkeymap(unsigned char port) {
	unsigned char res=0x1f;
	unsigned char i;
	for(i=0;i<8;i++) {
		if ((port&tmasks[i])==0) res=res&keyboardmap[7-i];
	}
	return res;
}

void releasekeys() {
	unsigned char i;
	for (i=0;i<8;i++) keyboardmap[i]=0xff;
}

//-------------

void initladrz() {
	ushort sadr=0x0000;
	ushort aadr=0x1800;
	int idx=0;
	uchar i,j,k,l;
	for (i=0;i<3;i++) {
		for (j=0;j<8;j++) {
			for (k=0;k<8;k++) {
				for (l=0;l<32;l++) {
					ladrz[idx][0]=sadr;
					ladrz[idx][1]=aadr;
					idx++;
					sadr++;
					aadr++;
				}
				sadr += 0xe0;	// -#20 +#100
				aadr -= 0x20;
			}
			sadr -= 0x7e0;		// -#800 +#20
			aadr += 0x20;
		}
		sadr += 0x700;			// -#100 +#800
	}
}