#ifndef _DEBUGER_H
#define _DEBUGER_H

#include <QDialog>

struct BPoint {
	uchar page;	// ram (adr>0x3fff) or rom (adr<0x4000)
	ushort adr;	// full addr (0x0000..0xffff);
};

class DebugWin : public QDialog {
	public:
		DebugWin(QWidget*);
		QList<BPoint> bpoint;
		bool active;
		void reject();
		void start();
		void stop();
		int findbp(BPoint);
	private:
		QGridLayout *rglay,*asmlay,*dmplay;
		uchar rowincol[16];
		ushort upadr,adr,dmpadr;
		uchar curcol, currow;
		bool fillall();
		void fillregz();
		bool filldasm();
		void filldump();
		ushort getprevadr(ushort);
		QString getdisasm();
	protected:
		void keyPressEvent(QKeyEvent*);
};

#endif

std::string comz[256][7] = {
	{"nop",		"",		"",		"rlc b",	"rlc b,(ix:5)",	"rlc b,(iy:5)",	"nop*"},
	{"ld bc,:2",	"",		"",		"rlc c",	"rlc c,(ix:5)",	"rlc c,(iy:5)",	"nop*"},
	{"ld (bc),a",	"",		"",		"rlc d",	"rlc d,(ix:5)",	"rlc d,(iy:5)",	"nop*"},
	{"inc bc",	"",		"",		"rlc e",	"rlc e,(ix:5)",	"rlc e,(iy:5)",	"nop*"},
	{"inc b",	"",		"",		"rlc h",	"rlc h,(ix:5)",	"rlc h,(iy:5)",	"nop*"},
	{"dec b",	"",		"",		"rlc l",	"rlc l,(ix:5)",	"rlc l,(iy:5)",	"nop*"},
	{"ld b,:1",	"",		"",		"rlc (hl)",	"rlc (ix:5)",	"rlc (iy:5)",	"nop*"},
	{"rlca",	"",		"",		"rlc a",	"rlc a,(ix:5)",	"rlc a,(iy:5)",	"nop*"},
	{"ex af,af'",	"",		"",		"rrc b",	"rrc b,(ix:5)",	"rrc b,(iy:5)",	"nop*"},
	{"add hl,bc",	"add ix,bc",	"add iy,bc",	"rrc c",	"rrc c,(ix:5)",	"rrc c,(iy:5)",	"nop*"},
	{"ld a,(bc)",	"",		"",		"rrc d",	"rrc d,(ix:5)",	"rrc d,(iy:5)",	"nop*"},
	{"dec bc",	"",		"",		"rrc e",	"rrc e,(ix:5)",	"rrc e,(iy:5)",	"nop*"},
	{"inc c",	"",		"",		"rrc h",	"rrc h,(ix:5)",	"rrc h,(iy:5)",	"nop*"},
	{"dec c",	"",		"",		"rrc l",	"rrc l,(ix:5)",	"rrc l,(iy:5)",	"nop*"},
	{"ld c,:1",	"",		"",		"rrc (hl)",	"rrc (ix:5)",	"rrc (iy:5)",	"nop*"},
	{"rrca",	"",		"",		"rrc a",	"rrc a,(ix:5)",	"rrc a,(iy:5)",	"nop*"},
	{"djnz :3",	"",		"",		"rl b",		"rl b,(ix:5)",	"rl b,(iy:5)",	"nop*"},
	{"ld de,:2",	"",		"",		"rl c",		"rl c,(ix:5)",	"rl c,(iy:5)",	"nop*"},
	{"ld (de),a",	"",		"",		"rl d",		"rl d,(ix:5)",	"rl d,(iy:5)",	"nop*"},
	{"inc de",	"",		"",		"rl e",		"rl e,(ix:5)",	"rl e,(iy:5)",	"nop*"},
	{"inc d",	"",		"",		"rl h",		"rl h,(ix:5)",	"rl h,(iy:5)",	"nop*"},
	{"dec d",	"",		"",		"rl l",		"rl l,(ix:5)",	"rl l,(iy:5)",	"nop*"},
	{"ld d,:1",	"",		"",		"rl (hl)",	"rl (ix:5)",	"rl (iy:5)",	"nop*"},
	{"rla",		"",		"",		"rl a",		"rl a,(ix:5)",	"rl a,(iy:5)",	"nop*"},
	{"jr :3",	"",		"",		"rr b",		"rr b,(ix:5)",	"rr b,(iy:5)",	"nop*"},
	{"add hl,de",	"add ix,de",	"add iy,de",	"rr c",		"rr c,(ix:5)",	"rr c,(iy:5)",	"nop*"},
	{"ld a,(de)",	"",		"",		"rr d",		"rr d,(ix:5)",	"rr d,(iy:5)",	"nop*"},
	{"dec de",	"",		"",		"rr e",		"rr e,(ix:5)",	"rr e,(iy:5)",	"nop*"},
	{"inc e",	"",		"",		"rr h",		"rr h,(ix:5)",	"rr h,(iy:5)",	"nop*"},
	{"dec e",	"",		"",		"rr l",		"rr l,(ix:5)",	"rr l,(iy:5)",	"nop*"},
	{"ld e,:1",	"",		"",		"rr (hl)",	"rr (ix:5)",	"rr (iy:5)",	"nop*"},
	{"rra",		"",		"",		"rr a",		"rr a,(ix:5)",	"rr a,(iy:5)",	"nop*"},
	{"jr nz,:3",	"",		"",		"sla b",	"sla b,(ix:5)",	"sla b,(iy:5)",	"nop*"},
	{"ld hl,:2",	"ld ix,:2",	"ld iy,:2",	"sla c",	"sla c,(ix:5)",	"sla c,(iy:5)",	"nop*"},
	{"ld (:2),hl",	"ld (:2),ix",	"ld (:2),iy"	"sla d",	"sla d,(ix:5)",	"sla d,(iy:5)",	"nop*"},
	{"inc hl",	"inc ix",	"inc iy",	"sla e",	"sla e,(ix:5)",	"sla e,(iy:5)",	"nop*"},
	{"inc h",	"inc hx",	"inc hy",	"sla h",	"sla h,(ix:5)",	"sla h,(iy:5)",	"nop*"},
	{"dec h",	"dec hx",	"dec hy",	"sla l",	"sla l,(ix:5)",	"sla l,(iy:5)",	"nop*"},
	{"ld h,:1",	"ld hx,:1",	"ld hy,:1",	"sla (hl)",	"sla (ix:5)",	"sla (iy:5)",	"nop*"},
	{"daa",		"",		"",		"sla a",	"sla a,(ix:5)",	"sla a,(iy:5)",	"nop*"},
	{"jr z,:3",	"",		"",		"sra b",	"sra b,(ix:5)",	"sra b,(iy:5)",	"nop*"},
	{"add hl,hl",	"add ix,ix",	"add iy,iy",	"sra c",	"sra c,(ix:5)",	"sra c,(iy:5)",	"nop*"},
	{"ld hl,(:2)",	"ld ix,(:2)",	"ld iy,(:2)",	"sra d",	"sra d,(ix:5)",	"sra d,(iy:5)",	"nop*"},
	{"dec hl",	"dec ix",	"dec iy",	"sra e",	"sra e,(ix:5)",	"sra e,(iy:5)",	"nop*"},
	{"inc l",	"inc lx",	"inc ly",	"sra h",	"sra h,(ix:5)",	"sra h,(iy:5)",	"nop*"},
	{"dec l",	"dec lx",	"dec ly",	"sra l",	"sra l,(ix:5)",	"sra l,(iy:5)",	"nop*"},
	{"ld l,:1",	"ld lx,:1",	"ld ly,:1",	"sra (hl)",	"sra (ix:5)",	"sra (iy:5)",	"nop*"},
	{"cpl",		"",		"",		"sra a",	"sra a,(ix:5)",	"sra a,(iy:5)",	"nop*"},
	{"jr nc,:3",	"",		"",		"sli b",	"sli b,(ix:5)",	"sli b,(iy:5)",	"nop*"},
	{"ld sp,:2",	"",		"",		"sli c",	"sli c,(ix:5)",	"sli c,(iy:5)",	"nop*"},
	{"ld (:2),a",	"",		"",		"sli d",	"sli d,(ix:5)",	"sli d,(iy:5)",	"nop*"},
	{"inc sp",	"",		"",		"sli e",	"sli e,(ix:5)",	"sli e,(iy:5)",	"nop*"},
	{"inc (hl)",	"inc (ix:4)",	"inc (ix:4)",	"sli h",	"sli h,(ix:5)",	"sli h,(iy:5)",	"nop*"},
	{"dec (hl)",	"dec (ix:4)",	"dec (ix:4)",	"sli l",	"sli l,(ix:5)",	"sli l,(iy:5)",	"nop*"},
	{"ld (hl),:1",	"ld (ix:4),:1",	"ld (ix:4),:1",	"sli (hl)",	"sli (ix:5)",	"sli (iy:5)",	"nop*"},
	{"scf",		"",		"",		"sli a",	"sli a,(ix:5)",	"sli a,(iy:5)",	"nop*"},
	{"jr c,:3",	"",		"",		"srl b",	"srl b,(ix:5)",	"srl b,(iy:5)",	"nop*"},
	{"add hl,sp",	"add ix,sp",	"add iy,sp",	"srl c",	"srl c,(ix:5)",	"srl c,(iy:5)",	"nop*"},
	{"ld a,(:2)",	"",		"",		"srl d",	"srl d,(ix:5)",	"srl d,(iy:5)",	"nop*"},
	{"dec sp",	"",		"",		"srl e",	"srl e,(ix:5)",	"srl e,(iy:5)",	"nop*"},
	{"inc a",	"",		"",		"srl h",	"srl h,(ix:5)",	"srl h,(iy:5)",	"nop*"},
	{"dec a",	"",		"",		"srl l",	"srl l,(ix:5)",	"srl l,(iy:5)",	"nop*"},
	{"ld a,:1",	"",		"",		"srl (hl)",	"srl (ix:5)",	"srl (iy:5)",	"nop*"},
	{"ccf",		"",		"",		"srl a",	"srl a,(ix:5)",	"srl a,(iy:5)",	"nop*"},
	
	{"ld b,b",	"",		"",		"bit 0,b",	"bit 0,(ix:5)",	"bit 0,(iy:5)",	"in b,(c)"},
	{"ld b,c",	"",		"",		"bit 0,c",	"bit 0,(ix:5)",	"bit 0,(iy:5)",	"out (c),b"},
	{"ld b,d",	"",		"",		"bit 0,d",	"bit 0,(ix:5)",	"bit 0,(iy:5)",	"sbc hl,bc"},
	{"ld b,e",	"",		"",		"bit 0,e",	"bit 0,(ix:5)",	"bit 0,(iy:5)",	"ld (:2),bc"},
	{"ld b,h",	"ld b,hx",	"ld b,hy",	"bit 0,h",	"bit 0,(ix:5)",	"bit 0,(iy:5)",	"neg"},
	{"ld b,l",	"ld b,lx",	"ld b,ly",	"bit 0,l",	"bit 0,(ix:5)",	"bit 0,(iy:5)",	"retn"},
	{"ld b,(hl)",	"ld b,(ix:4)",	"ld b,(iy:4)",	"bit 0,(hl)",	"bit 0,(ix:5)",	"bit 0,(iy:5)",	"im 0"},
	{"ld b,a",	"",		"",		"bit 0,a",	"bit 0,(ix:5)",	"bit 0,(iy:5)",	"ld i,a"},
	{"ld c,b",	"",		"",		"bit 1,b",	"bit 1,(ix:5)",	"bit 1,(iy:5)",	"in c,(c)"},
	{"ld c,c",	"",		"",		"bit 1,c",	"bit 1,(ix:5)",	"bit 1,(iy:5)",	"out (c),c"},
	{"ld c,d",	"",		"",		"bit 1,d",	"bit 1,(ix:5)",	"bit 1,(iy:5)",	"adc hl,bc"},
	{"ld c,e",	"",		"",		"bit 1,e",	"bit 1,(ix:5)",	"bit 1,(iy:5)",	"ld bc,(:2)"},
	{"ld c,h",	"ld c,hx",	"ld c,hy",	"bit 1,h",	"bit 1,(ix:5)",	"bit 1,(iy:5)",	"neg*"},
	{"ld c,l",	"ld c,lx",	"ld c,ly",	"bit 1,l",	"bit 1,(ix:5)",	"bit 1,(iy:5)",	"reti"},
	{"ld c,(hl)",	"ld c,(ix:4)",	"ld c,(iy:4)",	"bit 1,(hl)",	"bit 1,(ix:5)",	"bit 1,(iy:5)",	"im 0*"},
	{"ld c,a",	"",		"",		"bit 1,a",	"bit 1,(ix:5)",	"bit 1,(iy:5)",	"ld r,a"},
	{"ld d,b",	"",		"",		"bit 2,b",	"bit 2,(ix:5)",	"bit 2,(iy:5)",	"in d,(c)"},
	{"ld d,c",	"",		"",		"bit 2,c",	"bit 2,(ix:5)",	"bit 2,(iy:5)",	"out (c),d"},
	{"ld d,d",	"",		"",		"bit 2,d",	"bit 2,(ix:5)",	"bit 2,(iy:5)",	"sbc hl,de"},
	{"ld d,e",	"",		"",		"bit 2,e",	"bit 2,(ix:5)",	"bit 2,(iy:5)",	"ld (:2),de"},
	{"ld d,h",	"ld d,hx",	"ld d,hy",	"bit 2,h",	"bit 2,(ix:5)",	"bit 2,(iy:5)",	"neg*"},
	{"ld d,l",	"ld d,lx",	"ld d,ly",	"bit 2,l",	"bit 2,(ix:5)",	"bit 2,(iy:5)",	"retn*"},
	{"ld d,(hl)",	"ld d,(ix:4)",	"ld d,(iy:4)",	"bit 2,(hl)",	"bit 2,(ix:5)",	"bit 2,(iy:5)",	"im 1"},
	{"ld d,a",	"",		"",		"bit 2,a",	"bit 2,(ix:5)",	"bit 2,(iy:5)",	"ld a,i"},
	{"ld e,b",	"",		"",		"bit 3,b",	"bit 3,(ix:5)",	"bit 3,(iy:5)",	"in e,(c)"},
	{"ld e,c",	"",		"",		"bit 3,c",	"bit 3,(ix:5)",	"bit 3,(iy:5)",	"out (c),e"},
	{"ld e,d",	"",		"",		"bit 3,d",	"bit 3,(ix:5)",	"bit 3,(iy:5)",	"adc hl,de"},
	{"ld e,e",	"",		"",		"bit 3,e",	"bit 3,(ix:5)",	"bit 3,(iy:5)",	"ld de,(:2)"},
	{"ld e,h",	"ld e,hx",	"ld e,hy",	"bit 3,h",	"bit 3,(ix:5)",	"bit 3,(iy:5)",	"neg*"},
	{"ld e,l",	"ld e,lx",	"ld e,ly",	"bit 3,l",	"bit 3,(ix:5)",	"bit 3,(iy:5)",	"reti*"},
	{"ld e,(hl)",	"ld e,(ix:4)",	"ld e,(iy:4)",	"bit 3,(hl)",	"bit 3,(ix:5)",	"bit 3,(iy:5)",	"im 2"},
	{"ld e,a",	"",		"",		"bit 3,a",	"bit 3,(ix:5)",	"bit 3,(iy:5)",	"ld a,r"},
	{"ld h,b",	"ld hx,b",	"ld hy,b",	"bit 4,b",	"bit 4,(ix:5)",	"bit 4,(iy:5)",	"in h,(c)"},
	{"ld h,c",	"ld hx,c",	"ld hy,c",	"bit 4,c",	"bit 4,(ix:5)",	"bit 4,(iy:5)",	"out (c),h"},
	{"ld h,d",	"ld hx,d",	"ld hy,d",	"bit 4,d",	"bit 4,(ix:5)",	"bit 4,(iy:5)",	"sbc hl,hl"},
	{"ld h,e",	"ld hx,e",	"ld hy,e",	"bit 4,e",	"bit 4,(ix:5)",	"bit 4,(iy:5)",	"ld (:2),hl"},
	{"ld h,h",	"ld hx,hx",	"ld hy,hy",	"bit 4,h",	"bit 4,(ix:5)",	"bit 4,(iy:5)",	"neg*"},
	{"ld h,l",	"ld hx,lx",	"ld hy,ly",	"bit 4,l",	"bit 4,(ix:5)",	"bit 4,(iy:5)",	"retn*"},
	{"ld h,(hl)",	"ld h,(ix:4)",	"ld h,(iy:4)",	"bit 4,(hl)",	"bit 4,(ix:5)",	"bit 4,(iy:5)",	"im 0*"},
	{"ld h,a",	"ld hx,a",	"ld hy,a",	"bit 4,a",	"bit 4,(ix:5)",	"bit 4,(iy:5)",	"rrd"},
	{"ld l,b",	"ld lx,b",	"ld ly,b",	"bit 5,b",	"bit 5,(ix:5)",	"bit 5,(iy:5)",	"in l,(c)"},
	{"ld l,c",	"ld lx,c",	"ld ly,c",	"bit 5,c",	"bit 5,(ix:5)",	"bit 5,(iy:5)",	"out (c),l"},
	{"ld l,d",	"ld lx,d",	"ld ly,d",	"bit 5,d",	"bit 5,(ix:5)",	"bit 5,(iy:5)",	"sfc hl,hl"},
	{"ld l,e",	"ld lx,e",	"ld ly,e",	"bit 5,e",	"bit 5,(ix:5)",	"bit 5,(iy:5)",	"ld hl,(:2)"},
	{"ld l,h",	"ld lx,hx",	"ld ly,hy",	"bit 5,h",	"bit 5,(ix:5)",	"bit 5,(iy:5)",	"neg*"},
	{"ld l,l",	"ld lx,lx",	"ld ly,ly",	"bit 5,l",	"bit 5,(ix:5)",	"bit 5,(iy:5)",	"reti*"},
	{"ld l,(hl)",	"ld l,(ix:4)",	"ld l,(iy:4)",	"bit 5,(hl)",	"bit 5,(ix:5)",	"bit 5,(iy:5)",	"im 0*"},
	{"ld l,a",	"ld lx,a",	"ld ly,a",	"bit 5,a",	"bit 5,(ix:5)",	"bit 5,(iy:5)",	"rld"},
	{"ld (hl),b",	"ld (ix:4),b",	"ld (iy:4),b",	"bit 6,b",	"bit 6,(ix:5)",	"bit 6,(iy:5)",	"in *,(c)"},
	{"ld (hl),c",	"ld (ix:4),c",	"ld (iy:4),c",	"bit 6,c",	"bit 6,(ix:5)",	"bit 6,(iy:5)",	"out (c),*"},
	{"ld (hl),d",	"ld (ix:4),d",	"ld (iy:4),d",	"bit 6,d",	"bit 6,(ix:5)",	"bit 6,(iy:5)",	"sbc hl,sp"},
	{"ld (hl),e",	"ld (ix:4),e",	"ld (iy:4),e",	"bit 6,e",	"bit 6,(ix:5)",	"bit 6,(iy:5)",	"ld (:2),sp"},
	{"ld (hl),h",	"ld (ix:4),h",	"ld (iy:4),h",	"bit 6,h",	"bit 6,(ix:5)",	"bit 6,(iy:5)",	"neg*"},
	{"ld (hl),l",	"ld (ix:4),l",	"ld (iy:4),l",	"bit 6,l",	"bit 6,(ix:5)",	"bit 6,(iy:5)",	"retn*"},
	{"halt",	"",		"",		"bit 6,(hl)",	"bit 6,(ix:5)",	"bit 6,(iy:5)",	"im 1*"},
	{"ld (hl),a",	"ld (ix:4),a",	"ld (iy:4),a",	"bit 6,a",	"bit 6,(ix:5)",	"bit 6,(iy:5)",	"nop*"},
	{"ld a,b",	"",		"",		"bit 7,b",	"bit 7,(ix:5)",	"bit 7,(iy:5)",	"in a,(c)"},
	{"ld a,c",	"",		"",		"bit 7,c",	"bit 7,(ix:5)",	"bit 7,(iy:5)",	"out (c),a"},
	{"ld a,d",	"",		"",		"bit 7,d",	"bit 7,(ix:5)",	"bit 7,(iy:5)",	"adc hl,sp"},
	{"ld a,e",	"",		"",		"bit 7,e",	"bit 7,(ix:5)",	"bit 7,(iy:5)",	"ld sp,(:2)"},
	{"ld a,h",	"ld a,hx",	"ld a,hy",	"bit 7,h",	"bit 7,(ix:5)",	"bit 7,(iy:5)",	"neg*"},
	{"ld a,l",	"ld a,lx",	"ld a,ly",	"bit 7,l",	"bit 7,(ix:5)",	"bit 7,(iy:5)",	"reti*"},
	{"ld a,(hl)",	"ld a,(ix:4)",	"ld a,(iy:4)",	"bit 7,(hl)",	"bit 7,(ix:5)",	"bit 7,(iy:5)",	"im 2*"},
	{"ld a,a",	"",		"",		"bit 7,a",	"bit 7,(ix:5)",	"bit 7,(iy:5)",	"nop*"},

	{"add a,b",	"",		"",		"res 0,b",	"res 0,(ix:5)",	"res 0,(iy:5)",	"nop*"},
	{"add a,c",	"",		"",		"res 0,c",	"res 0,(ix:5)",	"res 0,(iy:5)",	"nop*"},
	{"add a,d",	"",		"",		"res 0,d",	"res 0,(ix:5)",	"res 0,(iy:5)",	"nop*"},
	{"add a,e",	"",		"",		"res 0,e",	"res 0,(ix:5)",	"res 0,(iy:5)",	"nop*"},
	{"add a,h",	"add a,hx",	"add a,hy",	"res 0,h",	"res 0,(ix:5)",	"res 0,(iy:5)",	"nop*"},
	{"add a,l",	"add a,lx",	"add a,ly",	"res 0,l",	"res 0,(ix:5)",	"res 0,(iy:5)",	"nop*"},
	{"add a,(hl)",	"add a,(ix:4)",	"add a,(ix:4)",	"res 0,(hl)",	"res 0,(ix:5)",	"res 0,(iy:5)",	"nop*"},
	{"add a,a",	"",		"",		"res 0,a",	"res 0,(ix:5)",	"res 0,(iy:5)",	"nop*"},
	{"adc a,b",	"",		"",		"res 1,b",	"res 1,(ix:5)",	"res 1,(iy:5)",	"nop*"},
	{"adc a,c",	"",		"",		"res 1,c",	"res 1,(ix:5)",	"res 1,(iy:5)",	"nop*"},
	{"adc a,d",	"",		"",		"res 1,d",	"res 1,(ix:5)",	"res 1,(iy:5)",	"nop*"},
	{"adc a,e",	"",		"",		"res 1,e",	"res 1,(ix:5)",	"res 1,(iy:5)",	"nop*"},
	{"adc a,h",	"adc a,hx",	"adc a,hy",	"res 1,h",	"res 1,(ix:5)",	"res 1,(iy:5)",	"nop*"},
	{"adc a,l",	"adc a,lx",	"adc a,ly",	"res 1,l",	"res 1,(ix:5)",	"res 1,(iy:5)",	"nop*"},
	{"adc a,(hl)",	"adc a,(ix:4)",	"adc a,(ix:4)",	"res 1,(hl)",	"res 1,(ix:5)",	"res 1,(iy:5)",	"nop*"},
	{"adc a,a",	"",		"",		"res 1,a",	"res 1,(ix:5)",	"res 1,(iy:5)",	"nop*"},
	{"sub b",	"",		"",		"res 2,b",	"res 2,(ix:5)",	"res 2,(iy:5)",	"nop*"},
	{"sub c",	"",		"",		"res 2,c",	"res 2,(ix:5)",	"res 2,(iy:5)",	"nop*"},
	{"sub d",	"",		"",		"res 2,d",	"res 2,(ix:5)",	"res 2,(iy:5)",	"nop*"},
	{"sub e",	"",		"",		"res 2,e",	"res 2,(ix:5)",	"res 2,(iy:5)",	"nop*"},
	{"sub h",	"sub hx",	"sub hy",	"res 2,h",	"res 2,(ix:5)",	"res 2,(iy:5)",	"nop*"},
	{"sub l",	"sub lx",	"sub ly",	"res 2,l",	"res 2,(ix:5)",	"res 2,(iy:5)",	"nop*"},
	{"sub (hl)",	"sub (ix:4)",	"sub (ix:4)",	"res 2,(hl)",	"res 2,(ix:5)",	"res 2,(iy:5)",	"nop*"},
	{"sub a",	"",		"",		"res 2,a",	"res 2,(ix:5)",	"res 2,(iy:5)",	"nop*"},
	{"sbc a,b",	"",		"",		"res 3,b",	"res 3,(ix:5)",	"res 3,(iy:5)",	"nop*"},
	{"sbc a,c",	"",		"",		"res 3,c",	"res 3,(ix:5)",	"res 3,(iy:5)",	"nop*"},
	{"sbc a,d",	"",		"",		"res 3,d",	"res 3,(ix:5)",	"res 3,(iy:5)",	"nop*"},
	{"sbc a,e",	"",		"",		"res 3,e",	"res 3,(ix:5)",	"res 3,(iy:5)",	"nop*"},
	{"sbc a,h",	"sbc a,hx",	"sbc a,hy",	"res 3,h",	"res 3,(ix:5)",	"res 3,(iy:5)",	"nop*"},
	{"sbc a,l",	"sbc a,lx",	"sbc a,ly",	"res 3,l",	"res 3,(ix:5)",	"res 3,(iy:5)",	"nop*"},
	{"sbc a,(hl)",	"sbc a,(ix:4)",	"sbc a,(ix:4)",	"res 3,(hl)",	"res 3,(ix:5)",	"res 3,(iy:5)",	"nop*"},
	{"sbc a,a",	"",		"",		"res 3,a",	"res 3,(ix:5)",	"res 3,(iy:5)",	"nop*"},
	{"and b",	"",		"",		"res 4,b",	"res 4,(ix:5)",	"res 4,(iy:5)",	"ldi"},
	{"and c",	"",		"",		"res 4,c",	"res 4,(ix:5)",	"res 4,(iy:5)",	"cpi"},
	{"and d",	"",		"",		"res 4,d",	"res 4,(ix:5)",	"res 4,(iy:5)",	"ini"},
	{"and e",	"",		"",		"res 4,e",	"res 4,(ix:5)",	"res 4,(iy:5)",	"outi"},
	{"and h",	"and hx",	"and hy",	"res 4,h",	"res 4,(ix:5)",	"res 4,(iy:5)",	"nop*"},
	{"and l",	"and lx",	"and ly",	"res 4,l",	"res 4,(ix:5)",	"res 4,(iy:5)",	"nop*"},
	{"and (hl)",	"and (ix:4)",	"and (ix:4)",	"res 4,(hl)",	"res 4,(ix:5)",	"res 4,(iy:5)",	"nop*"},
	{"and a",	"",		"",		"res 4,a",	"res 4,(ix:5)",	"res 4,(iy:5)",	"nop*"},
	{"xor b",	"",		"",		"res 5,b",	"res 5,(ix:5)",	"res 5,(iy:5)",	"ldd"},
	{"xor c",	"",		"",		"res 5,c",	"res 5,(ix:5)",	"res 5,(iy:5)",	"cpd"},
	{"xor d",	"",		"",		"res 5,d",	"res 5,(ix:5)",	"res 5,(iy:5)",	"ind"},
	{"xor e",	"",		"",		"res 5,e",	"res 5,(ix:5)",	"res 5,(iy:5)",	"outd"},
	{"xor h",	"xor hx",	"xor hy",	"res 5,h",	"res 5,(ix:5)",	"res 5,(iy:5)",	"nop*"},
	{"xor l",	"xor lx",	"xor ly",	"res 5,l",	"res 5,(ix:5)",	"res 5,(iy:5)",	"nop*"},
	{"xor (hl)",	"xor (ix:4)",	"xor (ix:4)",	"res 5,(hl)",	"res 5,(ix:5)",	"res 5,(iy:5)",	"nop*"},
	{"xor a",	"",		"",		"res 5,a",	"res 5,(ix:5)",	"res 5,(iy:5)",	"nop*"},
	{"or b",	"",		"",		"res 6,b",	"res 6,(ix:5)",	"res 6,(iy:5)",	"ldir"},
	{"or c",	"",		"",		"res 6,c",	"res 6,(ix:5)",	"res 6,(iy:5)",	"cpir"},
	{"or d",	"",		"",		"res 6,d",	"res 6,(ix:5)",	"res 6,(iy:5)",	"inir"},
	{"or e",	"",		"",		"res 6,e",	"res 6,(ix:5)",	"res 6,(iy:5)",	"otir"},
	{"or h",	"or hx",	"or hy",	"res 6,h",	"res 6,(ix:5)",	"res 6,(iy:5)",	"nop*"},
	{"or l",	"or lx",	"or ly",	"res 6,l",	"res 6,(ix:5)",	"res 6,(iy:5)",	"nop*"},
	{"or (hl)",	"or (ix:4)",	"or (ix:4)",	"res 6,(hl)",	"res 6,(ix:5)",	"res 6,(iy:5)",	"nop*"},
	{"or a",	"",		"",		"res 6,a",	"res 6,(ix:5)",	"res 6,(iy:5)",	"nop*"},
	{"cp b",	"",		"",		"res 7,b",	"res 7,(ix:5)",	"res 7,(iy:5)",	"lddr"},
	{"cp c",	"",		"",		"res 7,c",	"res 7,(ix:5)",	"res 7,(iy:5)",	"cpdr"},
	{"cp d",	"",		"",		"res 7,d",	"res 7,(ix:5)",	"res 7,(iy:5)",	"indr"},
	{"cp e",	"",		"",		"res 7,e",	"res 7,(ix:5)",	"res 7,(iy:5)",	"otdr"},
	{"cp h",	"cp hx",	"cp hy",	"res 7,h",	"res 7,(ix:5)",	"res 7,(iy:5)",	"nop*"},
	{"cp l",	"cp lx",	"cp ly",	"res 7,l",	"res 7,(ix:5)",	"res 7,(iy:5)",	"nop*"},
	{"cp (hl)",	"cp (ix:4)",	"cp (ix:4)",	"res 7,(hl)",	"res 7,(ix:5)",	"res 7,(iy:5)",	"nop*"},
	{"cp a",	"",		"",		"res 7,a",	"res 7,(ix:5)",	"res 7,(iy:5)",	"nop*"},

	{"ret nz",	"",		"",		"set 0,b",	"set 0,(ix:5)",	"set 0,(ix:5)",	"nop*"},
	{"pop bc",	"",		"",		"set 0,c",	"set 0,(ix:5)",	"set 0,(ix:5)",	"nop*"},
	{"jp nz,:2",	"",		"",		"set 0,d",	"set 0,(ix:5)",	"set 0,(ix:5)",	"nop*"},
	{"jp :2",	"",		"",		"set 0,e",	"set 0,(ix:5)",	"set 0,(ix:5)",	"nop*"},
	{"call nz,:2",	"",		"",		"set 0,h",	"set 0,(ix:5)",	"set 0,(ix:5)",	"nop*"},
	{"push bc",	"",		"",		"set 0,l",	"set 0,(ix:5)",	"set 0,(ix:5)",	"nop*"},
	{"add a,:1",	"",		"",		"set 0,(hl)",	"set 0,(ix:5)",	"set 0,(ix:5)",	"nop*"},
	{"rst 00",	"",		"",		"set 0,a",	"set 0,(ix:5)",	"set 0,(ix:5)",	"nop*"},
	{"ret z",	"",		"",		"set 1,b",	"set 1,(ix:5)",	"set 1,(ix:5)",	"nop*"},
	{"ret",		"",		"",		"set 1,c",	"set 1,(ix:5)",	"set 1,(ix:5)",	"nop*"},
	{"jp z,:2",	"",		"",		"set 1,d",	"set 1,(ix:5)",	"set 1,(ix:5)",	"nop*"},
	{"#CB",		"",		"",		"set 1,e",	"set 1,(ix:5)",	"set 1,(ix:5)",	"nop*"},
	{"call z,:2",	"",		"",		"set 1,h",	"set 1,(ix:5)",	"set 1,(ix:5)",	"nop*"},
	{"call :2",	"",		"",		"set 1,l",	"set 1,(ix:5)",	"set 1,(ix:5)",	"nop*"},
	{"adc a,:1",	"",		"",		"set 1,(hl)",	"set 1,(ix:5)",	"set 1,(ix:5)",	"nop*"},
	{"rst 08",	"",		"",		"set 1,b",	"set 1,(ix:5)",	"set 1,(ix:5)",	"nop*"},
	{"ret nc",	"",		"",		"set 2,b",	"set 2,(ix:5)",	"set 2,(ix:5)",	"nop*"},
	{"pop de",	"",		"",		"set 2,c",	"set 2,(ix:5)",	"set 2,(ix:5)",	"nop*"},
	{"jp nc,:2",	"",		"",		"set 2,d",	"set 2,(ix:5)",	"set 2,(ix:5)",	"nop*"},
	{"out (:1),a",	"",		"",		"set 2,e",	"set 2,(ix:5)",	"set 2,(ix:5)",	"nop*"},
	{"call nc,:2",	"",		"",		"set 2,h",	"set 2,(ix:5)",	"set 2,(ix:5)",	"nop*"},
	{"push de",	"",		"",		"set 2,l",	"set 2,(ix:5)",	"set 2,(ix:5)",	"nop*"},
	{"sub :1",	"",		"",		"set 2,(hl)",	"set 2,(ix:5)",	"set 2,(ix:5)",	"nop*"},
	{"rst 10",	"",		"",		"set 2,a",	"set 2,(ix:5)",	"set 2,(ix:5)",	"nop*"},
	{"ret c",	"",		"",		"set 3,b",	"set 3,(ix:5)",	"set 3,(ix:5)",	"nop*"},
	{"exx",		"",		"",		"set 3,c",	"set 3,(ix:5)",	"set 3,(ix:5)",	"nop*"},
	{"jp c,:2",	"",		"",		"set 3,d",	"set 3,(ix:5)",	"set 3,(ix:5)",	"nop*"},
	{"in a,(:1)",	"",		"",		"set 3,e",	"set 3,(ix:5)",	"set 3,(ix:5)",	"nop*"},
	{"call c,:2",	"",		"",		"set 3,h",	"set 3,(ix:5)",	"set 3,(ix:5)",	"nop*"},
	{"#DD",		"",		"",		"set 3,l",	"set 3,(ix:5)",	"set 3,(ix:5)",	"nop*"},
	{"sbc a,:1",	"",		"",		"set 3,(hl)",	"set 3,(ix:5)",	"set 3,(ix:5)",	"nop*"},
	{"rst 18",	"",		"",		"set 3,a",	"set 3,(ix:5)",	"set 3,(ix:5)",	"nop*"},
	{"ret po",	"",		"",		"set 4,b",	"set 4,(ix:5)",	"set 4,(ix:5)",	"nop*"},
	{"pop hl",	"pop ix",	"pop iy",	"set 4,c",	"set 4,(ix:5)",	"set 4,(ix:5)",	"nop*"},
	{"jp po,:2",	"",		"",		"set 4,d",	"set 4,(ix:5)",	"set 4,(ix:5)",	"nop*"},
	{"ex (sp),hl",	"ex (sp),ix",	"ex (sp),iy",	"set 4,e",	"set 4,(ix:5)",	"set 4,(ix:5)",	"nop*"},
	{"call po,:2",	"",		"",		"set 4,h",	"set 4,(ix:5)",	"set 4,(ix:5)",	"nop*"},
	{"push hl",	"push ix",	"push iy",	"set 4,l",	"set 4,(ix:5)",	"set 4,(ix:5)",	"nop*"},
	{"and :1",	"",		"",		"set 4,(hl)",	"set 4,(ix:5)",	"set 4,(ix:5)",	"nop*"},
	{"rst 20",	"",		"",		"set 4,a",	"set 4,(ix:5)",	"set 4,(ix:5)",	"nop*"},
	{"ret pe",	"",		"",		"set 5,b",	"set 5,(ix:5)",	"set 5,(ix:5)",	"nop*"},
	{"jp (hl)",	"jp (ix)",	"jp (iy)",	"set 5,c",	"set 5,(ix:5)",	"set 5,(ix:5)",	"nop*"},
	{"jp pe,:2",	"",		"",		"set 5,d",	"set 5,(ix:5)",	"set 5,(ix:5)",	"nop*"},
	{"ex de,hl",	"",		"",		"set 5,e",	"set 5,(ix:5)",	"set 5,(ix:5)",	"nop*"},
	{"call pe,:2",	"",		"",		"set 5,h",	"set 5,(ix:5)",	"set 5,(ix:5)",	"nop*"},
	{"#ED",		"",		"",		"set 5,l",	"set 5,(ix:5)",	"set 5,(ix:5)",	"nop*"},
	{"xor :1",	"",		"",		"set 5,(hl)",	"set 5,(ix:5)",	"set 5,(ix:5)",	"nop*"},
	{"rst 28",	"",		"",		"set 5,a",	"set 5,(ix:5)",	"set 5,(ix:5)",	"nop*"},
	{"ret p",	"",		"",		"set 6,b",	"set 6,(ix:5)",	"set 6,(ix:5)",	"nop*"},
	{"pop af",	"",		"",		"set 6,c",	"set 6,(ix:5)",	"set 6,(ix:5)",	"nop*"},
	{"jp p,:2",	"",		"",		"set 6,d",	"set 6,(ix:5)",	"set 6,(ix:5)",	"nop*"},
	{"di",		"",		"",		"set 6,e",	"set 6,(ix:5)",	"set 6,(ix:5)",	"nop*"},
	{"call p,:2",	"",		"",		"set 6,h",	"set 6,(ix:5)",	"set 6,(ix:5)",	"nop*"},
	{"push af",	"",		"",		"set 6,l",	"set 6,(ix:5)",	"set 6,(ix:5)",	"nop*"},
	{"or :1",	"",		"",		"set 6,(hl)",	"set 6,(ix:5)",	"set 6,(ix:5)",	"nop*"},
	{"rst 30",	"",		"",		"set 6,a",	"set 6,(ix:5)",	"set 6,(ix:5)",	"nop*"},
	{"ret m",	"",		"",		"set 7,b",	"set 7,(ix:5)",	"set 7,(ix:5)",	"nop*"},
	{"ld sp,hl",	"ls sp,ix",	"ld sp,iy",	"set 7,c",	"set 7,(ix:5)",	"set 7,(ix:5)",	"nop*"},
	{"jp m,:2",	"",		"",		"set 7,d",	"set 7,(ix:5)",	"set 7,(ix:5)",	"nop*"},
	{"ei",		"",		"",		"set 7,e",	"set 7,(ix:5)",	"set 7,(ix:5)",	"nop*"},
	{"call m,:2",	"",		"",		"set 7,h",	"set 7,(ix:5)",	"set 7,(ix:5)",	"nop*"},
	{"#FD",		"",		"",		"set 7,l",	"set 7,(ix:5)",	"set 7,(ix:5)",	"nop*"},
	{"cp :1",	"",		"",		"set 7,(hl)",	"set 7,(ix:5)",	"set 7,(ix:5)",	"nop*"},
	{"rst 38",	"",		"",		"set 7,a",	"set 7,(ix:5)",	"set 7,(ix:5)",	"nop*"}
};
